import { RnBootstrapToolbox } from './RnBootstrapToolbox';
export declare const GENERATOR_TEMPLATES_DIR = "generator-templates";
export declare enum FeaturePiece {
    container = "container",
    component = "component",
    hook = "hook",
    model = "model",
    page = "page",
    util = "util"
}
export declare enum AdditionalCodeGenerator {
    feature = "feature",
    test = "test"
}
export declare type FeaturePieceType = keyof typeof FeaturePiece;
export declare enum FeatureVariance {
    Default = "Default",
    StyledComponents = "StyledComponents"
}
export declare const GenerateFeatureOptionSelectionKey = "featureGenerationOptions";
export declare type GenerateFeaturePromptResult = {
    [GenerateFeatureOptionSelectionKey]: [FeaturePiece];
};
export declare const GenerateTestFilesSelectionKey = "generateTestFiles";
export declare type GenerateTestFilesSelectionPromptResult = {
    [GenerateTestFilesSelectionKey]: [string];
};
export declare const SupportedCommandsText: string;
export declare type GenericGeneratorRunner = (name: string) => Promise<void>;
export declare type GenericGeneratorValidator = (name?: string) => void | never;
export declare enum Template {
    Base = "Base",
    Tests = "Tests"
}
export declare type GeneratorConfig = {
    [key in Template]: string;
} & {
    Piece: FeaturePiece;
    Ext: string;
};
export declare const getGeneratorConfig: (piece: FeaturePiece, variance: FeatureVariance) => GeneratorConfig;
export declare const getFeaturePieceVariance: (toolbox: RnBootstrapToolbox, piece: FeaturePiece) => FeatureVariance;
export interface CodeGeneratorToolboxEntries {
    validateComponent: GenericGeneratorValidator;
    validateContainer: GenericGeneratorValidator;
    validateHook: GenericGeneratorValidator;
    validateModel: GenericGeneratorValidator;
    validatePage: GenericGeneratorValidator;
    validateUtil: GenericGeneratorValidator;
    validateFeature: GenericGeneratorValidator;
    generatePiece: (piece: FeaturePiece, name: string) => Promise<void>;
    generateFeature: GenericGeneratorRunner;
    generateTest: () => Promise<void>;
}
